@@ -75,12 +75,12 @@ class SerasaSerializer(BaseSchema):
 
     @pre_load
     def log_received_data(self, data, **kwargs) -> Dict[Any, Any]:
-        logger.debug(f"Request Data received is: {data}")
+        logger.info(f"Request Data received is: {data}")
         return data
 
     @post_load
     def make_data(self, data, **kwargs) -> SerasaData:
-        logger.debug(f"Deserialized Data received is: {data}")
+        logger.info(f"Deserialized Data received is: {data}")
         new_data = SerasaData(**data)
         new_data.datasource_base_url = Serasa.base_url
         logger.warning(
